These parameters are used in multiple coercion functions. They are defined here to make them easier to import and to find.
These dots are for future extensions and should be empty.
Logical. Are NA values ok?
Logical. Is NULL an acceptable value?
Logical. Are zero-length vectors acceptable?
Integer. The minimum size of the object. Object size will be
tested using vctrs::vec_size().
Integer. The maximum size of the object. Object size will be
tested using vctrs::vec_size().
The argument to stabilize.
Character. An argument name for x. The automatic value will work in most cases, or pass it through from higher-level functions to make error messages clearer in unexported functions.
Character. The class name of x to use in error messages. Use
this if you remove a special class from x before checking its coercion,
but want the error message to match the original class.
The execution environment of the call. See the call argument of
rlang::abort() for more information.