| are_chr_ish | R Documentation |
are_chr_ish() is a vectorized predicate function that checks
whether each element of its input can be safely coerced to a character
vector. are_character_ish() is a synonym of are_chr_ish().
is_chr_ish() is a scalar predicate function that checks if all elements
of its input can be safely coerced to a character vector.
is_character_ish() is a synonym of is_chr_ish().
are_chr_ish(x, ...)
is_chr_ish(x, ...)
are_character_ish(x, ...)
is_character_ish(x, ...)
## Default S3 method:
are_chr_ish(x, ..., depth = 1)
x |
The object to check. |
... |
Arguments passed to methods. |
depth |
|
are_chr_ish() returns a logical vector with the same length as the
input. is_chr_ish() returns a length-1 logical (TRUE or FALSE) for
the entire vector.
Other character functions:
specify_chr(),
stabilize_chr()
Other check functions:
are_dbl_ish(),
are_fct_ish(),
are_int_ish(),
are_lgl_ish()
are_chr_ish(letters)
is_chr_ish(letters)
are_chr_ish(1:10)
is_chr_ish(1:10)
are_chr_ish(list("a", 1, TRUE))
is_chr_ish(list("a", 1, TRUE))
are_chr_ish(list("a", 1, list(1, 2)))
is_chr_ish(list("a", 1, list(1, 2)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.