dot-check_function_allowed: Check whether functions are allowed

.check_function_allowedR Documentation

Check whether functions are allowed

Description

Check whether functions are allowed

Usage

.check_function_allowed(
  x,
  coerce_function = FALSE,
  x_arg = caller_arg(x),
  call = caller_env()
)

Arguments

x

The object to check.

coerce_function

⁠(length-1 logical)⁠ Should functions be coerced?

x_arg

⁠(length-1 character)⁠ The name of the argument being stabilized to use in error messages. The automatic value will work in most cases, or pass it through from higher-level functions to make error messages clearer in unexported functions.

call

(environment) The execution environment to mention as the source of error messages.

Value

NULL, invisibly, if x passes the check.


stbl documentation built on April 4, 2026, 5:06 p.m.