dot-check_specs_named: Check that all elements of a spec list are named

.check_specs_namedR Documentation

Check that all elements of a spec list are named

Description

Check that all elements of a spec list are named

Usage

.check_specs_named(..., .call = caller_env())

Arguments

...

Named stabilizer functions, such as ⁠stabilize_*⁠ functions (stabilize_chr(), etc) or functions produced by ⁠specify_*()⁠ functions (specify_chr(), etc). Each name corresponds to a required element in .x, and the function is used to validate that element.

.call

(environment) The execution environment to mention as the source of error messages.

Value

NULL, invisibly, if all elements are named.


stbl documentation built on April 4, 2026, 5:06 p.m.