dot-construct_specification_fn: Construct a specified stabilizer function

.construct_specification_fnR Documentation

Construct a specified stabilizer function

Description

Construct a specified stabilizer function

Usage

.construct_specification_fn(
  check_dupes,
  stabilizer,
  factory_args,
  ...,
  call = rlang::caller_env()
)

Arguments

check_dupes

(list) An empty list, or a list containing an expression that checks for duplicate arguments.

stabilizer

⁠(length-1 character)⁠ Name of the stabilizer function to call.

factory_args

Arguments passed to specify_cls() as ....

...

Not used. Included to avoid confusion in R CMD check.

call

(environment) The environment to use as the parent of the generated function. Defaults to the caller's environment.

Value

A function of class "stbl_specified_fn" that calls the specified stabilizer function with the provided arguments. The generated function will also accept ... for additional arguments to pass to the stabilizer function. You can copy/paste the body of the resulting function if you want to provide additional context or functionality.


stbl documentation built on April 4, 2026, 5:06 p.m.