dot-describe_failure_dbl_value: Describe a numeric value validation failure

.describe_failure_dbl_valueR Documentation

Describe a numeric value validation failure

Description

Describe a numeric value validation failure

Usage

.describe_failure_dbl_value(
  x,
  failure_locations,
  direction,
  target_value,
  x_arg
)

Arguments

x

(numeric) The vector being checked.

failure_locations

(integer) Indices where the check failed.

direction

(character) One of "low" or "high".

target_value

(numeric) The value against which x is being compared.

x_arg

⁠(length-1 character)⁠ The name of the argument being stabilized to use in error messages. The automatic value will work in most cases, or pass it through from higher-level functions to make error messages clearer in unexported functions.

Value

A named character vector for .stbl_abort().


stbl documentation built on April 4, 2026, 5:06 p.m.