dot-glue2: A wrapper for 'glue::glue' with custom delimiters

.glue2R Documentation

A wrapper for glue::glue with custom delimiters

Description

This wrapper sets the .open and .close arguments of glue::glue() to [ and ⁠]⁠, respectively. This allows for safe use of glue interpolation within messages that will be processed by cli::cli_abort(), which uses ⁠{⁠ and ⁠}⁠ for its own styling.

Usage

.glue2(..., env = caller_env())

Arguments

...

Arguments passed on to glue::glue(). Usually expects unnamed arguments but named arguments other than .envir, .open, and .close are acceptable.

env

The environment in which to evaluate the expressions.

Value

A character string with evaluated expressions.


stbl documentation built on Nov. 5, 2025, 6:02 p.m.