dot-stop_function: Abort because an argument must not be a function

.stop_functionR Documentation

Abort because an argument must not be a function

Description

Abort because an argument must not be a function

Usage

.stop_function(x_arg, call)

Arguments

x_arg

⁠(length-1 character)⁠ The name of the argument being stabilized to use in error messages. The automatic value will work in most cases, or pass it through from higher-level functions to make error messages clearer in unexported functions.

call

(environment) The execution environment to mention as the source of error messages.

Value

This function is called for its side effect of throwing an error and does not return a value.


stbl documentation built on April 4, 2026, 5:06 p.m.