dot-stop_must: Abort with a standardized "must" message

.stop_mustR Documentation

Abort with a standardized "must" message

Description

Abort with a standardized "must" message

Usage

.stop_must(
  msg,
  x_arg,
  call,
  additional_msg = NULL,
  subclass = NULL,
  message_env = call,
  parent = NULL,
  ...
)

Arguments

msg

(character) The core error message describing the requirement.

x_arg

⁠(length-1 character)⁠ An argument name for x. The automatic value will work in most cases, or pass it through from higher-level functions to make error messages clearer in unexported functions.

call

(environment) The execution environment to mention as the source of error messages.

additional_msg

(character) Optional, additional cli-formatted messages.

subclass

(character) Class(es) to assign to the error. Will be prefixed by "stbl-error-".

message_env

(environment) The execution environment to use to evaluate variables in error messages.

parent

A parent condition, as you might create during a rlang::try_fetch(). See rlang::abort() for additional information.

...

Additional parameters passed to cli::cli_abort() and on to rlang::abort().

Value

This function is called for its side effect of throwing an error and does not return a value.


stbl documentation built on Nov. 5, 2025, 6:02 p.m.