| .apply_regex_rule | R Documentation |
Apply a single regex rule to a character vector
.apply_regex_rule(rule, x, x_arg, call)
rule |
|
x |
The argument to stabilize. |
x_arg |
|
call |
|
A character vector of error messages if the rule fails, otherwise
NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.