| .check_x_no_more_than_y | R Documentation |
Check that one value is not greater than another
.check_x_no_more_than_y(
x,
y,
x_arg = caller_arg(x),
y_arg = caller_arg(y),
call = caller_env()
)
x |
The object to check. |
y |
The value to compare against. |
x_arg |
|
y_arg |
|
call |
|
NULL, invisibly, if x is not greater than y.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.