| .has_regex_pattern | R Documentation |
A wrapper around stringi::stri_detect_regex() and base::grepl() that
prefers the stringi implementation if the package is available.
.has_regex_pattern(x, regex)
x |
The argument to stabilize. |
regex |
|
A logical vector of matches in x to regex.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.