| .shared-params | R Documentation |
These parameters are used in multiple functions. They are defined here to make them easier to import and to find.
... |
Arguments passed to methods. |
allow_na |
|
allow_null |
|
allow_zero_length |
|
are_cls_ish_fn |
The |
call |
|
cast_fn |
|
check_cls_value_fn |
|
check_cls_value_fn_args |
|
coerce_character |
|
coerce_factor |
|
depth |
|
is_rlang_cls_scalar |
|
levels |
|
message_env |
( |
min_size |
|
min_value |
|
max_size |
|
max_value |
|
parent |
A parent condition, as you might create during a
|
regex |
|
subclass |
( |
to_class |
|
to_cls_args |
|
to_cls_fn |
|
to_cls_scalar_args |
|
to_cls_scalar_fn |
|
to_na |
|
to_type_obj |
An empty object of the target type (e.g., |
x |
The argument to stabilize. |
x_arg |
|
x_class |
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.