| .stop_bad_levels | R Documentation |
Throws a standardized error when values are not found in the provided factor levels.
.stop_bad_levels(x, bad_casts, levels, to_na, x_arg, call)
x |
The argument to stabilize. |
bad_casts |
|
levels |
|
to_na |
|
x_arg |
|
call |
|
This function is called for its side effect of throwing an error and does not return a value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.