| .stop_cant_coerce | R Documentation |
Abort with a standardized "can't coerce" message
.stop_cant_coerce(
from_class,
to_class,
x_arg,
call,
additional_msg = NULL,
message_env = call,
parent = NULL,
...
)
from_class |
|
to_class |
|
x_arg |
|
call |
|
additional_msg |
|
message_env |
( |
parent |
A parent condition, as you might create during a
|
... |
Additional parameters passed to |
This function is called for its side effect of throwing an error and does not return a value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.