| .stop_function | R Documentation |
Abort because an argument must not be a function
.stop_function(x_arg, call)
x_arg |
|
call |
|
This function is called for its side effect of throwing an error and does not return a value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.