| .stop_incompatible | R Documentation |
Abort with an "incompatible type" message
.stop_incompatible(
x_class,
to,
failures,
due_to,
x_arg,
call,
parent = NULL,
...
)
x_class |
|
to |
The target object for the coercion. |
failures |
|
due_to |
|
x_arg |
|
call |
|
parent |
A parent condition, as you might create during a
|
... |
Additional parameters passed to |
This function is called for its side effect of throwing an error and does not return a value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.