| .stop_must | R Documentation |
Abort with a standardized "must" message
.stop_must(
msg,
x_arg,
call,
additional_msg = NULL,
subclass = NULL,
message_env = call,
parent = NULL,
...
)
msg |
|
x_arg |
|
call |
|
additional_msg |
|
subclass |
( |
message_env |
( |
parent |
A parent condition, as you might create during a
|
... |
Additional parameters passed to |
This function is called for its side effect of throwing an error and does not return a value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.