| .stop_null | R Documentation |
Abort because an argument must not be NULL
.stop_null(x_arg, call, parent = NULL, ...)
x_arg |
|
call |
|
parent |
A parent condition, as you might create during a
|
... |
Additional parameters passed to |
This function is called for its side effect of throwing an error and does not return a value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.