regex_must_match: Create a regex matching rule

View source: R/regex.R

regex_must_matchR Documentation

Create a regex matching rule

Description

Attach a standardized error message to a regex argument. By default, the message will be "must match the regex pattern {regex}". If the input regex has a negate attribute set to TRUE, the message will instead be "must not match...". This message can be used with stabilize_chr() and stabilize_chr_scalar().

Usage

regex_must_match(regex)

Arguments

regex

(character) The regular expression pattern.

Value

The regex value with names() equal to the generated error message.

Examples

regex_must_match("[aeiou]")

# With negation:
regex <- "[aeiou]"
attr(regex, "negate") <- TRUE
regex_must_match(regex)

stbl documentation built on Nov. 5, 2025, 6:02 p.m.