| regex_must_not_match | R Documentation |
Attach a standardized error message to a regex argument that specifies
that the pattern must not be matched. This is a wrapper around
regex_must_match() that sets the negate attribute to TRUE.
regex_must_not_match(regex)
regex |
|
The regex value with a negate attribute and with names() equal
to the generated "must not match" error message.
regex_must_not_match("[aeiou]")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.